Boop.Config (BoopEx v1.0.0)

Copy Markdown View Source

Resolved configuration for a send. Values come from per-call options, then the :boop_ex application environment, then the BOOP_URL / BOOP_API_KEY environment variables.

Summary

Functions

Resolves configuration, with opts taking precedence over the application env.

Types

t()

@type t() :: %Boop.Config{
  api_key: String.t() | nil,
  enabled: boolean(),
  redact_keys: [String.t()],
  req_options: keyword(),
  source: String.t() | nil,
  timeout: pos_integer(),
  url: String.t() | nil
}

Functions

resolve(opts \\ [])

@spec resolve(keyword()) :: t()

Resolves configuration, with opts taking precedence over the application env.